
# Slot: unique_key_slots


list of slot names that form a key

URI: [linkml:unique_key_slots](https://w3id.org/linkml/unique_key_slots)


## Domain and Range

unique_key &#8594;  <sub>1..\*</sub> slot_definition

## Parents


## Children


## Used by

 * unique_key
